Welcome to Rucio’s documentation! — Rucio 1.2 documentation

# Welcome to Rucio’s documentation!

Rucio is a project that provides services and associated libraries for allowing scientific collaborations to manage large volumes of data spread across facilities at multiple institutions and organisations. Rucio has been developed by the ATLAS experiment.

Rucio offers advanced features, is highly scalable and modular. It is a data management solution that could cover the needs of different communities in the scientific domain (e.g., HEP, astronomy, biology).

This documentation is generated by the Sphinx toolkit. and lives in the source tree.

# General Information

This section contains the general information related to Rucio which is common to all developers, users and operators. For documentation specific to the any of these three, please see the subsequent sections.

- Concepts and terminology
- Typical replica workflow
- Architecture
- Release notes

# Developer Documentation

If you want to develop with Rucio or contribute to the project, this part of the documentation is for you.

- Contributor Guide
- Setting up a Rucio development environment
- RESTful APIs
- The Client API Reference
- Database operations

# User Documentation

- Installing Rucio Clients
- Rucio CLI: Examples
- Rucio CLI
- Rucio Administrative CLI
- RSE Expressions
- Rucio Clients
- Errors and Exceptions
- Advanced Usage

# Operator Documentation

- Installing Rucio server
- Installing Rucio daemons
- Daemons CLIs
- Monitoring

# Rucio Tutorial

- Setting up a Rucio demo environment
- Rucio demo
- Rucio CLI: Examples
- Rucio administration CLI: Examples

# Authors

- Individual contributors to the source code
- Organisations employing contributors